@@ -1,4 +1,5 @@
 import logging.config
+import re
 import socket
 import time
 import warnings
@@ -134,12 +135,13 @@ class OSMRegion:
                 # Convert relation result to OSMRailwayLine objects
                 if rou_result.result:
                     for rel in rou_result.result.relations:
-                        rel_way_ids = [mem.ref for mem in rel.members if type(mem) == overpy.RelationWay and not mem.role]
-                        rel_ways = [w for w in rou_result.result.ways if w.id in rel_way_ids]
+                        rel_way_ids = [mem.ref for mem in rel.members if
+                                       type(mem) == overpy.RelationWay and not mem.role]
+
+                        rel_ways = [w for w in trk_result.result.ways if w.id in rel_way_ids]
 
                         sort_order = {id: idx for id, idx in zip(rel_way_ids, range(len(rel_way_ids)))}
                         rel_ways.sort(key=lambda w: sort_order[w.id])
-
                         self.railway_lines.append(OSMRailwayLine(rel.id, rel_ways, rel.tags, rel.members))
 
                 if trk_result.result:
@@ -191,7 +193,7 @@ class OSMRegion:
                 logger.warning("Socket timeout, retrying".format(e))
         else:
             logger.warning("Could download OSM data via Overpass after %d attempts with query: %s" % (attempts,
-                                                                                                            query))
+                                                                                                      query))
             return None
 
     def get_all_route_nodes(self) -> list:
@@ -239,6 +241,20 @@ class OSMRegion:
         """
         return [el for el in self.railway_elements if type(el) == OSMLevelCrossing]
 
+    def get_railway_line(self, name) -> [OSMRailwayLine]:
+        """ Get railway line by name. Always returns a list, even if only one line is found that matches the name
+
+        Parameters
+        ----------
+        name: str
+            Name of the railway line that should be searched
+
+        Returns
+        -------
+            list
+        """
+        return [line for line in self.railway_lines if re.search(r'\b{0}\b'.format(name), line.name)]
+
     @property
     def lon_sw(self):
         return self._lon_sw
